<?php
/**
 *  消息列表
 *  @author  system
 *  @version    1.0
 *  @date 2017-06-30 10:16:20
 *
 */
namespace App\Http\Controllers\Admin\System;
use App\Http\Controllers\Admin\Controller;
use App\Models\SystemInfoModel;
use App\Models\UserInfoModel;
use Illuminate\Http\Request;
use App\Repositories\Base\Criteria\OrderBy;
use App\Repositories\System\Criteria\MultiWhere;
use App\Repositories\System\InfoRepository;

class InfoController extends Controller
{
    private $repository;

    public function __construct(InfoRepository $repository) {
        if(!$this->repository) $this->repository = $repository;
    }

    function index(Request $reqeust) {
        $search['keyword'] = $reqeust->input('keyword');
        $query = $this->repository->pushCriteria(new MultiWhere($search));
        $request = $reqeust->all();
        if(isset($request['sort_field']) && $request['sort_field'] && isset($request['sort_field_by'])) {
        $query = $query->pushCriteria(new OrderBy($request['sort_field'],$request['sort_field_by']));
        }
        $list = $query->paginate();
        foreach ($list as $item) {
            $user = UserInfoModel::find($item->user_id);
            $item->nickname = empty($user) ? '' : $user->nickname;
        }
        return view('admin.system.info.index',compact('list'));
    }


    function check(Request $reqeust) {
        $request = $reqeust->all();
        $search['keyword'] = $reqeust->input('keyword');
        $orderby = array();
        if(isset($request['sort_field']) && $request['sort_field'] && isset($request['sort_field_by'])) {
            $orderby[$request['sort_field']] = $request['sort_field_by'];
        }
        $list = $this->repository->search($search,$orderby);
        return view('admin.system.info.check',compact('list'));
    }


    /**
     * 添加
     * 
     */
    public function create(Request $reqeust)
    {
        if($reqeust->method() == 'POST') {
            return $this->_createSave();
        }
        return view('admin.system.info.edit');
    }

    /**
     * 保存修改
     */
    private function _createSave(){
        $data = (array) request('data');
        $id = $this->repository->create($data);
        if($id) {
            $url[] = array('url'=>U( 'System/Info/index'),'title'=>'返回列表');
            $url[] = array('url'=>U( 'System/Info/create'),'title'=>'继续添加');
            $this->showMessage('添加成功',$url);
        }else{
            $url[] = array('url'=>U( 'System/Info/index'),'title'=>'返回列表');
            return $this->showWarning('添加失败',$url);
        }
    }
    
    /**
     * 
     * 修改
     * 
     * 
     */
    public function update(Request $reqeust) {
        if($reqeust->method() == 'POST') {
            return $this->_updateSave();
        }
        $data = $this->repository->find($reqeust->get('id'));
        return view('admin.system.info.edit',compact('data'));
    }

    /**
     * 保存修改
     */
    private function _updateSave() {
        $data = (array) request('data');
        $ok = $this->repository->update(request('id'),$data);
        if($ok) {
            $url[] = array('url'=>U( 'System/Info/index'),'title'=>'返回列表');
            return $this->showMessage('操作成功',urldecode(request('_referer')));
        }else{
            $url[] = array('url'=>U( 'System/Info/index'),'title'=>'返回列表');
            return $this->showWarning('操作失败',$url);
        }
    }

    public function view(Request $reqeust) {
        $data = $this->repository->find(request('id'));
        return view('admin.system.info.view',compact('data'));
    }


    /**
     *
     * 状态改变
     *
     */
    public function status(Request $reqeust) {
        $ok = $this->repository->updateStatus(request('id'),request('status'));
        if($ok) {
            return $this->showMessage('操作成功');
        }else{
            return $this->showWarning('操作失败');
        }
    }
    
    /**
     * 删除
     */
    public function destroy(Request $reqeust) {
        $bool = $this->repository->destroy($reqeust->get('id'));
        if($bool) {
            return  $this->showMessage('操作成功');
        }else{
            return  $this->showWarning("操作失败");
        }
    }

    public function systemInfo(Request $request)
    {
        $users = UserInfoModel::select('id')->get()->toArray();
        if (empty($users))  return 404;
        $message = $request->msg;
        $arr = [] ;
        foreach ($users as $user) {
            $arr[] = [
                'user_id' =>$user['id'],
                'message' =>$message,
                'created_at'=>date("Y-m-d H:i:s"),
                'updated_at'=>date("Y-m-d H:i:s"),
            ];
        }
        $ok = SystemInfoModel::insert($arr);
        if ($ok) {
            return 200;
        }else{
            return 500;
        }
    }
}